# Code: Sangdon Lim

rstudioapi::restartSession()

library(PROsetta)
library(mirt)
library(mvnfast)
library(stringr)
library(devEMF)

d_original <- loadData(
  response  = "dat_dePHQ9_original.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)
d_validation <- loadData(
  response  = "dat_dePHQ9_validation.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)

# Figure 2

set.seed(1)
ipar_original   <- runCalibration(d_original, fixedpar = TRUE)
set.seed(1)
ipar_validation <- runCalibration(d_validation, fixedpar = TRUE)

theta_grid <- seq(-4, 4, .1)

for (img_format in c("eps", "emf", "svg")) {

  setEPS()
  if (img_format == "eps") postscript("figures/Figure 2.eps", width = 9, height = 9)
  if (img_format == "emf") emf(file = "figures/Figure 2.emf", width = 9, height = 9)
  if (img_format == "svg") svg(file = "figures/Figure 2.svg", width = 9, height = 9)

  par(
    mfrow = c(3, 3),
    mai = c(0.5, 0.5, 0.2, 0.2),
    oma = c(3, 3, 3, 3)
  )

  for (phq_item in getItemNames(d_original, 2)) {

    item_original   <- extract.item(ipar_original, phq_item)
    item_validation <- extract.item(ipar_validation, phq_item)
    scores_original   <- expected.item(item_original  , theta_grid)
    scores_validation <- expected.item(item_validation, theta_grid)

    plot(
      0, 0, type = "n",
      xlim = range(theta_grid), ylim = c(0, 3),
      xlab = "", ylab = "",
      axes = F)

    axis(1)
    axis(2, at = seq(0, 3, 1))

    lines(theta_grid, scores_original  , col = "blue")
    lines(theta_grid, scores_validation, col = "red", lty = 2)

    box(lwd = 1)

    if (phq_item == "PHQ91") item_text = "Little interest"
    if (phq_item == "PHQ92") item_text = "Feeling down"
    if (phq_item == "PHQ93") item_text = "Sleep"
    if (phq_item == "PHQ94") item_text = "Feeling tired"
    if (phq_item == "PHQ95") item_text = "Eating"
    if (phq_item == "PHQ96") item_text = "Feeling bad"
    if (phq_item == "PHQ97") item_text = "Concentration"
    if (phq_item == "PHQ98") item_text = "Slow or fidgety"
    if (phq_item == "PHQ99") item_text = "Suicidal thoughts"

    item_text <- sprintf("%s: %s", phq_item, item_text)
    mtext(item_text, side = 3, outer = FALSE)

    if (phq_item == "PHQ91") {
      legend(
        "topleft",
        c("Original", "Validation"),
        col = c("blue", "red"),
        lty = c(1, 2)
      )
    }

  }

  mtext("Theta", side = 1, cex = 1.2, outer = TRUE)
  mtext("Expected score", side = 2, cex = 1.2, outer = TRUE)

  dev.off()

}
