# Code: Sangdon Lim

rstudioapi::restartSession()

library(stringr)
library(devEMF)

fp    <- file.path("results")
f_all <- list.files(fp)
corr  <- seq(1.0, 0.6, -0.05)
out_all <- as.data.frame(matrix(NA, 0, 4))

for (r in corr) {

  tmp <- sprintf("out_%s_", r)
  idx <- str_detect(f_all, tmp)
  fs  <- f_all[idx]

  out <- as.data.frame(matrix(NA, length(fs), 4))

  for (i in 1:length(fs)) {

    d <- read.csv(file.path(fp, fs[i]))
    diff_uni  <- d$rhs_theta_uni  - d$rhs_theta
    diff_eqp  <- d$rhs_theta_eqp  - d$rhs_theta
    diff_cp   <- d$rhs_theta_cp   - d$rhs_theta
    rmse_uni  <- sqrt(mean((diff_uni )**2))
    rmse_eqp  <- sqrt(mean((diff_eqp )**2))
    rmse_cp   <- sqrt(mean((diff_cp  )**2))
    out[i, ] <- c(r, rmse_uni, rmse_eqp, rmse_cp)

  }

  out_all <- rbind(out_all, out)

}

out_avg <- aggregate(
  out_all, by = list(out_all[, 1]),
  function(x) sqrt(mean(x**2))
)[, -1]

colnames(out_avg) <- c("corr", "uni", "eqp", "cp")

idx <- order(out_avg$corr, decreasing = TRUE)
out_avg <- out_avg[idx, ]

# Figure 7

for (img_format in c("eps", "emf", "svg")) {

  setEPS()
  if (img_format == "eps") postscript("figures/Figure 7.eps", width = 7, height = 7)
  if (img_format == "emf") emf(file = "figures/Figure 7.emf", width = 7, height = 7)
  if (img_format == "svg") svg(file = "figures/Figure 7.svg", width = 7, height = 7)

  plot(
    out_avg[, 1], out_avg[, 1], type = "n",
    xlab = "Latent correlation", ylab = "RMSE",
    xlim = c(1.0, 0.6),
    ylim = c(0.0, 1.0))

  grid()

  lines(out_avg$corr, out_avg$uni , lty = 3, col = "black")
  lines(out_avg$corr, out_avg$eqp , lty = 2, col = "magenta")
  lines(out_avg$corr, out_avg$cp  , lty = 1, col = "lime green")

  legend("topleft",
    c("Unidimensional IRT", "Equipercentile", "Calibrated projection"),
    col = c("black", "magenta", "lime green"),
    lty = c(3, 2, 1),
    lwd = 1,
    bg = "white")

  box()

  dev.off()

}
