library(PROsetta)
library(mirt)

d <- loadData(
  response  = "dat_dePHQ9_validation.csv",
  itemmap   = "imap_dePHQ9.csv",
  anchor    = "anchor_dePHQ9.csv",
  input_dir = "data"
)

lhs_scale <- 2
rhs_scale <- 1

# Raw scores
X_lhs <- getResponse(d, lhs_scale)
X_rhs <- getResponse(d, rhs_scale)
out <- data.frame(
  lhs_raw = apply(X_lhs, 1, sum),
  rhs_raw = apply(X_rhs, 1, sum)
)

# Observed EAP T-scores
ipar_anchor <- d@anchor[, 3:7]

theta_grid <- seq(-4, 4, 0.05)
prior_mu_sigma <- list()
prior_mu_sigma$mu    <- 0
prior_mu_sigma$sigma <- matrix(1, 1, 1)

tmp_rsss  <- PROsetta:::getRSSS(
  ipar_anchor, theta_grid, is_minscore_0 = FALSE, prior_mu_sigma
)
table_OBS <- tmp_rsss
table_OBS$tscore <- table_OBS$eap * 10 + 50
table_OBS <- table_OBS[, c(1, 2)]
names(table_OBS)[2] <- "observed"

out <- merge(out, table_OBS, by.x = "rhs_raw", by.y = "sum_score")
apply(out, 2, mean)
apply(out, 2, sd)

# Linked scores (UNI)
set.seed(1)
tmp_calib <- runLinking(d, method = "FIXEDPAR")
tmp_rsss  <- runRSSS(
  d, tmp_calib, min_score = c(1, 0, 1),
  min_theta = -4.0, max_theta = 4.0, inc = 0.05
)
table_UNI <- tmp_rsss[[as.character(lhs_scale)]]
table_UNI$tscore <- table_UNI$eap * 10 + 50
table_UNI <- table_UNI[, c(1, 2)]
names(table_UNI)[2] <- "linked_UNI"

out <- merge(out, table_UNI, by.x = "lhs_raw", by.y = "raw_2")
apply(out, 2, mean)
apply(out, 2, sd)

UNI_vs_observed <- out$linked_UNI - out$observed
mean(UNI_vs_observed)
sd(UNI_vs_observed)

# Linked scores (EQP)
set.seed(1)
tmp <- runEquateObserved(
  d,
  smooth     = "loglinear",
  scale_from = lhs_scale,
  scale_to   = rhs_scale,
  type_to    = "theta",
  rsss       = tmp_rsss,
  degrees    = list(6, 1),
  reps       = 1000
)
table_EQP <- tmp$concordance
table_EQP$tscore_1 <- table_EQP$theta_1 * 10 + 50
table_EQP <- table_EQP[, c(1, 5)]
names(table_EQP)[2] <- "linked_EQP"

out <- merge(out, table_EQP, by.x = "lhs_raw", by.y = "raw_2")
apply(out, 2, mean)
apply(out, 2, sd)

# Linked scores (CP)
set.seed(1)
tmp_calib <- runLinking(d, method = "CP")
tmp_rsss  <- runRSSS(
  d, tmp_calib, min_score = c(1, 0, 1),
  min_theta = -4.0, max_theta = 4.0, inc = 0.05
)
table_CP <- tmp_rsss[[as.character(lhs_scale)]]
table_CP$tscore_dim1 <- table_CP$eap_dim1 * 10 + 50
table_CP <- table_CP[, c(1, 2)]
names(table_CP)[2] <- "linked_CP"

out <- merge(out, table_CP, by.x = "lhs_raw", by.y = "raw_2")
apply(out, 2, mean)
apply(out, 2, sd)

# Aggregate

delta <- out$linked_UNI - out$observed
mean(delta)
sd(delta)
sqrt(mean(delta) ** 2)

delta <- out$linked_EQP - out$observed
mean(delta)
sd(delta)
sqrt(mean(delta) ** 2)

delta <- out$linked_CP - out$observed
mean(delta)
sd(delta)
sqrt(mean(delta) ** 2)

